==> vplus-0.2.0-sources.jar: tech/nevets/vplus/blocks/VerticalSlabs.java <==
package tech.nevets.vplus.blocks;

import net.minecraft.block.*;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2383;
import net.minecraft.class_2464;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_3486;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;


public class VerticalSlabs extends class_2383 {
    private static final class_265 NORTH_SHAPE;
    private static final class_265 EAST_SHAPE;
    private static final class_265 SOUTH_SHAPE;
    private static final class_265 WEST_SHAPE;
    public static final class_2746 WATERLOGGED = class_2741.field_12508;

    public VerticalSlabs(class_2251 settings){
        super(settings);
        this.method_9590(this.field_10647.method_11664().method_11657(WATERLOGGED, true).method_11657(field_11177, class_2350.field_11043));
    }

    //TODO Fix Waterlogging
    @Override
    public class_3610 method_9545(class_2680 blockState_1) {
        return (Boolean)blockState_1.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(blockState_1);
    }

    @Override
    public class_2464 method_9604(class_2680 blockState_1) {
        return class_2464.field_11458;
    }

    @Override
    public class_2680 method_9605(class_1750 itemPlacementContext) {
        class_3610 fluidState = itemPlacementContext.method_8045().method_8316(itemPlacementContext.method_8037());
        boolean waterLog = fluidState.method_15767(class_3486.field_15517) && fluidState.method_15761() == 8;
        return super.method_9605(itemPlacementContext).method_11657(WATERLOGGED, waterLog)
                .method_11657(field_11177, itemPlacementContext.method_8042().method_10153());
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(WATERLOGGED, field_11177);
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 , class_2338 , class_3726 ) {
        switch(state.method_11654(field_11177)) {
            case field_11043: return NORTH_SHAPE;
            case field_11034: return EAST_SHAPE;
            case field_11035: return SOUTH_SHAPE;
            case field_11039: return WEST_SHAPE;
            default: return super.method_9530(state, , , );
        }
    }

    static {
        class_265 shape = method_9541(0.0D, 0.0D, 0.0D, 8.0D, 16.0D, 16.0D);

        EAST_SHAPE = shape;
        NORTH_SHAPE = rotate(class_2350.field_11034, class_2350.field_11043, shape);
        SOUTH_SHAPE = rotate(class_2350.field_11034, class_2350.field_11035, shape);
        WEST_SHAPE = rotate(class_2350.field_11034, class_2350.field_11039, shape);
    }

    private static class_265 rotate(class_2350 from, class_2350 to, class_265 shape) {
        class_265[] buffer = new class_265[]{ shape, class_259.method_1073() };

        int times = (to.method_10161() - from.method_10161() + 4) % 4;
        for (int i = 0; i < times; i++) {
            buffer[0].method_1089((minX, minY, minZ, maxX, maxY, maxZ) -> buffer[1] = class_259.method_1084(buffer[1], class_259.method_1081(1-maxZ, minY, minX, 1-minZ, maxY, maxX)));
            buffer[0] = buffer[1];
            buffer[1] = class_259.method_1073();
        }

        return buffer[0];
    }
}

==> vplus-1.1.1-sources.jar: tech/nevets/vplus/blocks/VerticalSlabs.java <==
package tech.nevets.vplus.blocks;

import net.minecraft.block.*;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2383;
import net.minecraft.class_2464;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_3486;
import net.minecraft.class_3610;
import net.minecraft.class_3612;
import net.minecraft.class_3726;


public class VerticalSlabs extends class_2383 {
    private static final class_265 NORTH_SHAPE;
    private static final class_265 EAST_SHAPE;
    private static final class_265 SOUTH_SHAPE;
    private static final class_265 WEST_SHAPE;
    public static final class_2746 WATERLOGGED = class_2741.field_12508;

    public VerticalSlabs(class_2251 settings){
        super(settings);
        this.method_9590(this.field_10647.method_11664().method_11657(WATERLOGGED, true).method_11657(field_11177, class_2350.field_11043));
    }

    //TODO Fix Waterlogging
    @Override
    public class_3610 method_9545(class_2680 blockState_1) {
        return (Boolean)blockState_1.method_11654(WATERLOGGED) ? class_3612.field_15910.method_15729(false) : super.method_9545(blockState_1);
    }

    @Override
    public class_2464 method_9604(class_2680 blockState_1) {
        return class_2464.field_11458;
    }

    @Override
    public class_2680 method_9605(class_1750 itemPlacementContext) {
        class_3610 fluidState = itemPlacementContext.method_8045().method_8316(itemPlacementContext.method_8037());
        boolean waterLog = fluidState.method_15767(class_3486.field_15517) && fluidState.method_15761() == 8;
        return super.method_9605(itemPlacementContext).method_11657(WATERLOGGED, waterLog)
                .method_11657(field_11177, itemPlacementContext.method_8042().method_10153());
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(WATERLOGGED, field_11177);
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 view, class_2338 pos, class_3726 context) {
        switch(state.method_11654(field_11177)) {
            case field_11043: return NORTH_SHAPE;
            case field_11034: return EAST_SHAPE;
            case field_11035: return SOUTH_SHAPE;
            case field_11039: return WEST_SHAPE;
            default: return super.method_9530(state, view, pos, context);
        }
    }

    static {
        class_265 shape = method_9541(0.0D, 0.0D, 0.0D, 8.0D, 16.0D, 16.0D);

        EAST_SHAPE = shape;
        NORTH_SHAPE = rotate(class_2350.field_11034, class_2350.field_11043, shape);
        SOUTH_SHAPE = rotate(class_2350.field_11034, class_2350.field_11035, shape);
        WEST_SHAPE = rotate(class_2350.field_11034, class_2350.field_11039, shape);
    }

    private static class_265 rotate(class_2350 from, class_2350 to, class_265 shape) {
        class_265[] buffer = new class_265[]{ shape, class_259.method_1073() };

        int times = (to.method_10161() - from.method_10161() + 4) % 4;
        for (int i = 0; i < times; i++) {
            buffer[0].method_1089((minX, minY, minZ, maxX, maxY, maxZ) -> buffer[1] = class_259.method_1084(buffer[1], class_259.method_1081(1-maxZ, minY, minX, 1-minZ, maxY, maxX)));
            buffer[0] = buffer[1];
            buffer[1] = class_259.method_1073();
        }

        return buffer[0];
    }
}
